require 'redmine'

require_dependency 'project_subscription_hook'

Rails.logger.info 'Starting Project Subscription Plugin for Redmine'

ActiveRecord::Base.observers << :version_observer
ActiveRecord::Base.observers << :repository_observer
ActiveRecord::Base.observers << :changeset_observer
ActiveRecord::Base.observers << :board_observer

Rails.configuration.to_prepare do
    unless Project.included_modules.include?(ProjectSubscriptionPatch)
        Project.send(:include, ProjectSubscriptionPatch)
    end
    if Redmine::VERSION::MAJOR > 1
        unless Issue.included_modules.include?(IssueSubscriptionPatch)
            Issue.send(:include, IssueSubscriptionPatch)
        end
        unless Journal.included_modules.include?(JournalSubscriptionPatch)
            Journal.send(:include, JournalSubscriptionPatch)
        end
    end
    unless News.included_modules.include?(NewsSubscriptionPatch)
        News.send(:include, NewsSubscriptionPatch)
    end
    unless WikiContent.included_modules.include?(WikiContentSubscriptionPatch)
        WikiContent.send(:include, WikiContentSubscriptionPatch)
    end
    unless Mailer.included_modules.include?(MailerSubscriptionPatch)
        Mailer.send(:include, MailerSubscriptionPatch)
    end
    unless Redmine::Notifiable.included_modules.include?(NotifiableSubscriptionPatch)
        Redmine::Notifiable.send(:include, NotifiableSubscriptionPatch)
    end

    if Project.respond_to?(:add_available_column)
        Project.add_available_column(ExtendedColumn.new(:subscriptions,
                                                        :caption => :label_subscription_plural,
                                                        :value => lambda { |project| ProjectSubscriber.count(:conditions => [ "project_id = ?", project.id ]) },
                                                        :align => :center))
    end
    if User.respond_to?(:add_available_column)
        User.add_available_column(ExtendedColumn.new(:subscriptions,
                                                     :caption => :label_subscription_plural,
                                                     :value => lambda { |user| ProjectSubscriber.count(:conditions => [ "user_id = ?", user.id ]) },
                                                     :align => :center))
    end
end

Redmine::Plugin.register :subscription do
    name 'Subscription'
    author 'Andriy Lesyuk'
    author_url 'http://www.andriylesyuk.com/'
    description 'Adds ability to subscribe to project news, releases etc.'
    url 'http://projects.andriylesyuk.com/projects/subscription'
    version '0.0.1b'

    project_module :subscription do
        permission :subscribe_to_project, { :subscriptions => [ :subscription, :subscribe, :unsubscribe ] }
        permission :view_number_of_subscribers, {}
    end
end
