require_dependency 'journal'

module JournalSubscriptionPatch

    def self.included(base)
        base.send(:include, InstanceMethods)
        base.class_eval do
            unloadable

            alias_method_chain :notified_users, :subscribers
        end
    end

    module InstanceMethods

        def notified_users_with_subscribers
            notified = notified_users_without_subscribers

            if new_status && new_status.is_closed?
                issue = journalized.reload

                if issue.project.module_enabled?(:subscription)
                    subscribers          = ProjectSubscriber.find_all_by_project_id(issue.project.id)
                    notified_subscribers = subscribers.select{ |subscriber| subscriber.subscribed_to?(:closed_issues) &&
                                                                            subscriber.user.allowed_to?(:subscribe_to_project, issue.project) &&
                                                                            issue.visible?(subscriber.user)
                                                             }.collect(&:user)
                    unless notified_subscribers.empty?
                        notified_subscribers.reject!{ |user| !user.allowed_to?(:view_private_notes, journalized.project) } if private_notes?

                        notified += notified_subscribers
                        notified.uniq!
                    end
                end
            end

            notified
        end

    end

end
